@@ -39,8 +39,9 @@
     embedderMessageAck(id, arg) {
       const callback = this._callbacks[id];
       delete this._callbacks[id];
-      if (callback)
+      if (callback) {
         callback(arg);
+      }
     }
 
     /**
@@ -50,11 +51,13 @@
      */
     sendMessageToEmbedder(method, args, callback) {
       const callId = ++this._lastCallId;
-      if (callback)
+      if (callback) {
         this._callbacks[callId] = callback;
+      }
       const message = {'id': callId, 'method': method};
-      if (args.length)
+      if (args.length) {
         message.params = args;
+      }
       DevToolsHost.sendMessageToEmbedder(JSON.stringify(message));
     }
 
@@ -80,10 +83,11 @@
         // The addExtensions command is sent as the onload event happens for
         // DevTools front-end. We should buffer this command until the frontend
         // is ready for it.
-        if (this._addExtensionCallback)
+        if (this._addExtensionCallback) {
           extensions.forEach(this._addExtensionCallback);
-        else
+        } else {
           this._pendingExtensionDescriptors.pushAll(extensions);
+        }
       }
     }
 
@@ -249,6 +253,10 @@
       }
     }
 
+    reattachMainTarget() {
+      this._dispatchOnInspectorFrontendAPI('reattachMainTarget', []);
+    }
+
     /**
      * @param {boolean} hard
      */
@@ -287,10 +295,11 @@
      */
     setInspectedTabId(tabId) {
       // Support for legacy front-ends (<M41).
-      if (window['WebInspector'] && window['WebInspector']['setInspectedTabId'])
+      if (window['WebInspector'] && window['WebInspector']['setInspectedTabId']) {
         window['WebInspector']['setInspectedTabId'](tabId);
-      else
+      } else {
         this._dispatchOnInspectorFrontendAPI('setInspectedTabId', [tabId]);
+      }
     }
 
     /**
@@ -387,8 +396,9 @@
       // Support for legacy (<57) frontends.
       if (window.Runtime && window.Runtime.queryParam) {
         const panelToOpen = window.Runtime.queryParam('panel');
-        if (panelToOpen)
+        if (panelToOpen) {
           window.DevToolsAPI.showPanel(panelToOpen);
+        }
       }
     }
 
@@ -558,8 +568,9 @@
      */
     recordEnumeratedHistogram(actionName, actionCode, bucketSize) {
       // Support for M49 frontend.
-      if (actionName === 'DevTools.DrawerShown')
+      if (actionName === 'DevTools.DrawerShown') {
         return;
+      }
       DevToolsAPI.sendMessageToEmbedder('recordEnumeratedHistogram', [actionName, actionCode, bucketSize], null);
     }
 
@@ -706,6 +717,7 @@
     }
 
     /**
+     * Only needed to run Lighthouse on old devtools.
      * @override
      * @param {function()} callback
      */
@@ -1073,16 +1085,18 @@
     function objectObserve(object, observer) {
       if (window['WebInspector']) {
         const settingPrototype = /** @type {!Object} */ (window['WebInspector']['Setting']['prototype']);
-        if (typeof settingPrototype['remove'] === 'function')
+        if (typeof settingPrototype['remove'] === 'function') {
           settingPrototype['remove'] = settingRemove;
+        }
       }
       /** @type {!Set<string>} */
       const changedProperties = new Set();
       let scheduled = false;
 
       function scheduleObserver() {
-        if (scheduled)
+        if (scheduled) {
           return;
+        }
         scheduled = true;
         setImmediate(callObserver);
       }
@@ -1128,8 +1142,9 @@
         });
       }
 
-      for (let i = 0; i < properties.length; ++i)
+      for (let i = 0; i < properties.length; ++i) {
         defineProperty(properties[i]);
+      }
     }
 
     window.Object.observe = objectObserve;
@@ -1201,20 +1216,23 @@
    */
   function keyCodeToKeyIdentifier(keyCode) {
     let result = staticKeyIdentifiers.get(keyCode);
-    if (result !== undefined)
+    if (result !== undefined) {
       return result;
+    }
     result = 'U+';
     const hexString = keyCode.toString(16).toUpperCase();
-    for (let i = hexString.length; i < 4; ++i)
+    for (let i = hexString.length; i < 4; ++i) {
       result += '0';
+    }
     result += hexString;
     return result;
   }
 
   function installBackwardsCompatibility() {
     const majorVersion = getRemoteMajorVersion();
-    if (!majorVersion)
+    if (!majorVersion) {
       return;
+    }
 
     /** @type {!Array<string>} */
     const styleRules = [];
@@ -1235,15 +1253,17 @@
 
       const origAdd = DOMTokenList.prototype.add;
       DOMTokenList.prototype.add = function(...tokens) {
-        if (tokens[0].startsWith('insertion-point') || tokens[0].startsWith('tabbed-pane-header'))
+        if (tokens[0].startsWith('insertion-point') || tokens[0].startsWith('tabbed-pane-header')) {
           this._myElement.slot = '.' + tokens[0];
+        }
         return origAdd.apply(this, tokens);
       };
 
       const origCreateElement = Document.prototype.createElement;
       Document.prototype.createElement = function(tagName, ...rest) {
-        if (tagName === 'content')
+        if (tagName === 'content') {
           tagName = 'slot';
+        }
         const element = origCreateElement.call(this, tagName, ...rest);
         element.classList._myElement = element;
         return element;
@@ -1255,31 +1275,33 @@
         }
       });
 
-      // Document.prototype.createElementWithClass is a DevTools method, so we
-      // need to wait for DOMContentLoaded in order to override it.
-      if (window.document.head &&
-          (window.document.readyState === 'complete' || window.document.readyState === 'interactive'))
-        overrideCreateElementWithClass();
-      else
-        window.addEventListener('DOMContentLoaded', overrideCreateElementWithClass);
-
       function overrideCreateElementWithClass() {
         window.removeEventListener('DOMContentLoaded', overrideCreateElementWithClass);
 
         const origCreateElementWithClass = Document.prototype.createElementWithClass;
         Document.prototype.createElementWithClass = function(tagName, className, ...rest) {
-          if (tagName !== 'button' || (className !== 'soft-dropdown' && className !== 'dropdown-button'))
+          if (tagName !== 'button' || (className !== 'soft-dropdown' && className !== 'dropdown-button')) {
             return origCreateElementWithClass.call(this, tagName, className, ...rest);
+          }
           const element = origCreateElementWithClass.call(this, 'div', className, ...rest);
           element.tabIndex = 0;
           element.role = 'button';
           return element;
         };
       }
+
+      // Document.prototype.createElementWithClass is a DevTools method, so we
+      // need to wait for DOMContentLoaded in order to override it.
+      if (window.document.head &&
+          (window.document.readyState === 'complete' || window.document.readyState === 'interactive')) {
+        overrideCreateElementWithClass();
+      } else {
+        window.addEventListener('DOMContentLoaded', overrideCreateElementWithClass);
+      }
     }
 
     // Custom Elements V0 polyfill
-    if (majorVersion <= 73 && !Document.prototype.registerElement) {
+    if (majorVersion <= 73 && !Document.prototype.hasOwnProperty('registerElement')) {
       const fakeRegistry = new Map();
       Document.prototype.registerElement = function(typeExtension, options) {
         const {prototype, extends: localName} = options;
@@ -1288,13 +1310,15 @@
           const element = document.createElement(localName || typeExtension);
           const skip = new Set(['constructor', '__proto__']);
           for (const key of Object.keys(Object.getOwnPropertyDescriptors(prototype.__proto__ || {}))) {
-            if (skip.has(key))
+            if (skip.has(key)) {
               continue;
+            }
             element[key] = prototype[key];
           }
           element.setAttribute('is', typeExtension);
-          if (element['createdCallback'])
+          if (element['createdCallback']) {
             element['createdCallback']();
+          }
           return element;
         };
         fakeRegistry.set(typeExtension, callback);
@@ -1304,8 +1328,9 @@
       const origCreateElement = Document.prototype.createElement;
       Document.prototype.createElement = function(tagName, fakeCustomElementType) {
         const fakeConstructor = fakeRegistry.get(fakeCustomElementType);
-        if (fakeConstructor)
+        if (fakeConstructor) {
           return fakeConstructor();
+        }
         return origCreateElement.call(this, tagName, fakeCustomElementType);
       };
 
@@ -1315,8 +1340,9 @@
       //   classList.toggle('a');
       const originalDOMTokenListToggle = DOMTokenList.prototype.toggle;
       DOMTokenList.prototype.toggle = function(token, force) {
-        if (arguments.length === 1)
+        if (arguments.length === 1) {
           force = !this.contains(token);
+        }
         return originalDOMTokenListToggle.call(this, token, !!force);
       };
     }
@@ -1334,8 +1360,9 @@
          */
         ShadowRoot.prototype.elementFromPoint = function(x, y) {
           const originalResult = ShadowRoot.prototype.__originalShadowRootElementFromPoint.apply(this, arguments);
-          if (this.host && originalResult === this.host)
+          if (this.host && originalResult === this.host) {
             return null;
+          }
           return originalResult;
         };
       }
@@ -1353,8 +1380,9 @@
       });
     }
 
-    if (majorVersion <= 50)
+    if (majorVersion <= 50) {
       installObjectObserve();
+    }
 
     if (majorVersion <= 45) {
       /**
@@ -1388,8 +1416,9 @@
       window.CSSPrimitiveValue = CSSPrimitiveValue;
     }
 
-    if (majorVersion <= 45)
+    if (majorVersion <= 45) {
       styleRules.push('* { min-width: 0; min-height: 0; }');
+    }
 
     if (majorVersion <= 51) {
       // Support for quirky border-image behavior (<M51), see:
@@ -1403,8 +1432,9 @@
           '.coverage-toolbar-container, .animation-timeline-toolbar-container, .computed-properties { flex-basis: auto; }');
     }
 
-    if (majorVersion <= 50)
+    if (majorVersion <= 50) {
       Event.prototype.deepPath = undefined;
+    }
 
     if (majorVersion <= 54) {
       window.FileError = /** @type {!function (new: FileError) : ?} */ ({
@@ -1424,8 +1454,9 @@
   function getRemoteMajorVersion() {
     try {
       const remoteVersion = new URLSearchParams(window.location.search).get('remoteVersion');
-      if (!remoteVersion)
+      if (!remoteVersion) {
         return null;
+      }
       const majorVersion = parseInt(remoteVersion.split('.')[0], 10);
       return majorVersion;
     } catch (e) {
@@ -1437,8 +1468,9 @@
    * @param {!Array<string>} styleRules
    */
   function installExtraStyleRules(styleRules) {
-    if (!styleRules.length)
+    if (!styleRules.length) {
       return;
+    }
     const styleText = styleRules.join('\n');
     document.head.appendChild(createStyleElement(styleText));
 
@@ -1456,7 +1488,6 @@
    */
   function createStyleElement(styleText) {
     const style = document.createElement('style');
-    style.type = 'text/css';
     style.textContent = styleText;
     return style;
   }
